@@ -5,11 +5,11 @@ from river.core.instanceworkflowobject import InstanceWorkflowObject
 from river.core.workflowregistry import workflow_registry
 
 
+# noinspection PyMethodMayBeStatic
 class RiverObject(object):
 
-    def __init__(self, owner, field_name):
+    def __init__(self, owner):
         self.owner = owner
-        self.field_name = field_name
         self.is_class = inspect.isclass(owner)
 
     def __getattr__(self, field_name):
@@ -17,9 +17,12 @@ class RiverObject(object):
         if field_name not in workflow_registry.workflows[id(cls)]:
             raise Exception("Workflow with name:%s doesn't exist for class:%s" % (field_name, cls.__name__))
         if self.is_class:
-            return ClassWorkflowObject(self.owner, field_name, self.field_name)
+            return ClassWorkflowObject(self.owner, field_name)
         else:
-            return InstanceWorkflowObject(self.owner, field_name, self.field_name)
+            return InstanceWorkflowObject(self.owner, field_name)
 
     def all(self, cls):
-        return list([getattr(self, field_name) for field_name in workflow_registry.workflows[id(cls)]])
\ No newline at end of file
+        return list([getattr(self, field_name) for field_name in workflow_registry.workflows[id(cls)]])
+
+    def all_field_names(self, cls):  # pylint: disable=no-self-use
+        return [field_name for field_name in workflow_registry.workflows[id(cls)]]
