@@ -8,5 +8,8 @@ class WorkflowRegistry(object):
         self.workflows[id(cls)].add(name)
         self.class_index[id(cls)] = cls
 
+    def get_class_fields(self, model):
+        return self.workflows[id(model)]
 
-workflow_registry = WorkflowRegistry()
\ No newline at end of file
+
+workflow_registry = WorkflowRegistry()
