@@ -3,14 +3,17 @@ from __future__ import unicode_literals
 from django.db import models
 from django.db.models.signals import pre_save
 from django.template.defaultfilters import slugify
-from django.utils.encoding import python_2_unicode_compatible
+
+try:
+    from django.utils.encoding import python_2_unicode_compatible
+except ImportError:
+    from six import python_2_unicode_compatible
+
 from django.utils.translation import ugettext_lazy as _
 
 from river.models.base_model import BaseModel
 from river.models.managers.state import StateManager
 
-__author__ = 'ahmetdal'
-
 
 @python_2_unicode_compatible
 class State(BaseModel):
@@ -46,7 +49,6 @@ def on_pre_save(sender, instance, *args, **kwargs):
     if not instance.slug:
         instance.slug = slugify(instance.label)
     else:
-        # To be sure it is slug
         instance.slug = slugify(instance.slug)
 
 
