@@ -1,6 +1,3 @@
-__author__ = 'ahmetdal'
-
-
 class ErrorCode(object):
     NO_AVAILABLE_INITIAL_STATE = 1
     NO_AVAILABLE_FINAL_STATE = 2
@@ -11,3 +8,5 @@ class ErrorCode(object):
 
     MULTIPLE_STATE_FIELDS = 7
     NO_STATE_FIELD = 8
+    ALREADY_SKIPPED = 9
+    STATE_IS_NOT_AVAILABLE_TO_BE_JUMPED = 10
